*******************************************************************************************
** Script to create trend graphs for Figure 5													 **
*******************************************************************************************
use "$datapath/Chapman_QJPS_2018analysis.dta",clear

*******************************************************************************************
** 	Graphs with variables
*******************************************************************************************
// Generate variables with average spending for i) towns before matching (after stage 1) ii) matched towns
tempvar temp1 temp3 temp4 
qui: gen `temp1'=pcNexpCurrentTotal if excludeStage1==0
qui: bysort financialYearStart nonmb: egen `temp3'=total(`temp1')
qui: bysort financialYearStart nonmb: egen `temp4'=count(`temp1')
qui: gen grAllpcNexpCurrentTotal=`temp3'/`temp4'
drop `temp1'  `temp3' `temp4' 
qui: gen `temp1'=pcNexpCurrentTotal if usedWeight==1
qui: bysort financialYearStart nonmb: egen `temp3'=total(`temp1')
qui: bysort financialYearStart nonmb: egen `temp4'=count(`temp1')
qui: gen grCEMpcNexpCurrentTotal=`temp3'/`temp4'
drop `temp1'  `temp3' `temp4' 

#delimit;
twoway scatter grAllpcNexpCurrentTotal financialYearStart 
	if nonmb==0 
	, connect(l) msymbol(o)
	|| scatter grAllpcNexpCurrentTotal financialYearStart
	if nonmb==1
	, connect(l) msymbol(s)
	ytitle("Current expenditure p.c.") 
	legend(label(1 "Incorporated") label(2 "Unincorporated"))
	yscale(r(0.4 1.5)) 
	ylabel(0.4(0.2)1.5, labsize(small))  
	xscale(r(1883 1903)) 
	xlabel(1883(5)1903, labsize(small)) 
	xtitle("") 
	xline(1894)
	graphregion(fcolor(white) lcolor(black))
	title("Before matching", size(small))
	name(TrAllpcNexpCurrentTotal, replace)
	nodraw			  
;

twoway scatter grCEMpcNexpCurrentTotal financialYearStart 
	if nonmb==0
	,  connect(l) msymbol(o)
	|| scatter grCEMpcNexpCurrentTotal financialYearStart 
	if nonmb==1
	, connect(l) msymbol(s) 
	ytitle("Current expenditure p.c.") 
	legend(label(1 "Incorporated") label(2 "Unincorporated"))
	yscale(r(0.4 1.5))
	ylabel(0.4(0.2)1.5, labsize(small))
	xscale(r(1883 1903)) 
	xlabel(1883(5)1903, labsize(small))
	xtitle("")
	xline(1894)
	graphregion(fcolor(white) lcolor(black)) 
	title("After matching", size(small))
	name(TrCEMpcNexpCurrentTotal, replace)
	nodraw
;

twoway	scatter grAllpcNexpCurrentTotal financialYearStart 
	if nonmb==0 & financialYearStart>=1883&financialYearStart<=1893
	,  connect(l) msymbol(o)
	|| scatter grAllpcNexpCurrentTotal financialYearStart 
	if nonmb==1  & financialYearStart>=1883&financialYearStart<=1893
	, connect(l) msymbol(s)  
	ytitle("Current expenditure p.c.") 
	legend(label(1 "Incorporated") label(2 "Unincorporated"))
	yscale(r(0.4 1.2))
	ylabel(0.4(0.2)1.2, labsize(small))
	xscale(r(1883 1893)) 
	xlabel(1883(5)1893, labsize(small)) 
	xtitle("") 
	xline(1894) 
	graphregion(fcolor(white) lcolor(black)) 
	title("Before matching", size(small)) 
	name(TrAllpcNexpCurrentTotal2, replace) 
	nodraw			  
;
		  
twoway scatter grCEMpcNexpCurrentTotal financialYearStart 
	if nonmb==0 & financialYearStart>=1883&financialYearStart<=1893
	,  connect(l) msymbol(o)
	|| scatter grCEMpcNexpCurrentTotal financialYearStart 
	if nonmb==1  & financialYearStart>=1883&financialYearStart<=1893
	, connect(l) msymbol(s) 
	ytitle("Current expenditure p.c.") 
	legend(label(1 "Incorporated") label(2 "Unincorporated"))
	yscale(r(0.4 1.2))
	ylabel(0.4(0.2)1.2, labsize(small))
	xscale(r(1883 1893))
	xlabel(1883(5)1893, labsize(small))
	xtitle("")
	xline(1894)
	graphregion(fcolor(white) lcolor(black)) 
	title("After matching", size(small)) 
	name(TrCEMpcNexpCurrentTotal2, replace) 
	nodraw			
;

// Combine graphs	
grc1leg  TrAllpcNexpCurrentTotal2 TrCEMpcNexpCurrentTotal2 TrAllpcNexpCurrentTotal TrCEMpcNexpCurrentTotal
	, graphregion(fcolor(white) lwidth(large) lcolor(white));

// Export graph
graph export "$outputpath/figure5.tif",replace width(3543);

#delimit cr


