******************************************************************************************
** Runs regressions for Figure 6															 	**
**																						**
** NOTE BEFORE RUNNING: 																	**
** Control variables are defined by global macro $controls										**
******************************************************************************************
use "$datapath/Chapman_QJPS_2018analysis.dta",clear

******************************************************************************************
** Preliminaries: define sample 
******************************************************************************************
// Keep those without missing data to ensure same dataset across specifications
keep if forRegression==1

// Drop those not in matched sample
keep if usedWeight==1&middleClassTown==1
******************************************************************************************

******************************************************************************************
** Regression
******************************************************************************************
// Include leads 			  
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal dummyYear1883-dummyYear1893 dummyYear1895-dummyYear1902
	nonmb_x_dummyYear1883-nonmb_x_dummyYear1893 nonmb_x_dummyYear1895-nonmb_x_dummyYear1902  
	$controls
	, vce(cluster id) fe;
	estadd local financialYearEndfe "Y" , replace;
	estadd local fixed "Y" , replace;
	estadd local controls "Y" , replace;								
	estadd local linearTrends "N" , replace;					
	estadd local quadraticTrends "N" , replace;					
testparm nonmb_x_dummyYear1885-nonmb_x_dummyYear1894;
#delimit cr
parmest, saving("$outputpath/estimatesWithLeads", replace)

************************************************************************************
** Coefficient plot
************************************************************************************							  
use "$outputpath/estimatesWithLeads", clear
keep if strpos(parm,"nonmb_x_dummy")==1 /** Keep estimates for interaction dummies **/
** Insert observation for missing category in 1894-5
local new = _N + 1
set obs `new'
replace parm="nonmb_x_dummyYear1894" if _n==_N
replace estimate=0 if parm=="nonmb_x_dummyYear1894"
replace min95=0 if parm=="nonmb_x_dummyYear1894"
replace max95=0 if parm=="nonmb_x_dummyYear1894"
sort parm
gen parmid = _n
#delimit;        
eclplot estimate min95 max95 parmid,
	estopts(mcolor(black))
	eplottype(line)
	rplottype(rcap)
	ciopts(color(gs10) lwidth(medium))
	/* title("Upper-class controlled towns", color(black))*/
	ytitle("Current expenditure per capita (standardized)")
	ylabel(,angle(horizontal)) yscale(range(-0.8(0.2)0.2) titlegap(*-5)) 
	ylabel(-0.8 -0.6 -0.4 -0.2 0 0.2, angle(horizontal)) 
	xtick(1(2)19)
	xlabel(1 "1883" 3 "1885" 5 "1887" 7 "1889" 
		9 "1891"  11 "1893" 13 "1895" 
		15 "1897" 17 "1899" 19 "1901")
	xtitle("")
	graphregion(color(gs16))
	yline(0, lcolor(black) lwidth(medthick)) 
	xline(12,lcolor(red) lwidth(medthick))
	/** xsize(10) ysize(7.5) **/
	name(gr_estimatesWithLeads, replace);

#delimit cr 					  
************************************************************************************
// Output
************************************************************************************
cd "$outputpath"
gr export "figure6.tif",replace name(gr_estimatesWithLeads) width(3543)

erase "$outputpath/estimatesWithLeads.dta"

	
	
