******************************************************************************************
** Script identifies the characteristics of households with differing numbers of servants				**		
** using the 1881 census																	**	
******************************************************************************************

/** 
******************************************************************************************
** Code to create subset of data included in the replication package from download of 100%  
** census sample from NAPP data (https://www.nappdata.org/) from the full census
******************************************************************************************
use "$datapath/1881censusPrecollapse.dta",clear
	** Identify those in institutions s Students, military, members of religious orders,  
	** institutional or foundlings/orphans 
	gen institution=1 if ((relate>=1221&relate<=1301)|relate==1301)
	bysort serial: egen numInstitutional=total(institution)

	**Keep heads of household, removing places with more than 50 people
	keep if relate==101&numInstitutional==0&numperhh<=50  
	// Drop those in  London or in channel islands and similar
	keep if subdis>=30000&subdis<631000

	keep servants occgb ordergb
	"$datapath/1881censusData.dta"
**/

******************************************************************************************
** Use subset of 1881 census data and log results for tables and figures
******************************************************************************************
use "$datapath/1881censusData.dta", clear

log using "$outputpath/Figure2andTable1",text replace

******************************************************************************************
** Percentages of households with more than 1 or 1 servant
******************************************************************************************
count 
count if servants>0 
count if servants>1
di 583812/4565359 /**12.8% **/
di 209643/4565359 /**4.6% **/

******************************************************************************************
** Figure II  (use .ado file "fre")
******************************************************************************************
// Identify top/bottom 10 occupational orders for each group

// Households with 1 servant
fre ordergb if servants==1&occgb~=999, tabulate(10) descending
// Households with >1 servant
fre ordergb if servants>1&occgb~=999, tabulate(10) descending

log off

******************************************************************************************
** Table I: % of servants within each occupation group
******************************************************************************************
// Generate average number of households with 1 / >1 servants by occupation
gen temp1servant=1 if servants==1
replace temp1servant=0 if servants==0|servants>1
gen tempOver1servant=1 if servants>=2&servants<.
replace tempOver1servant=0 if servants<2|servants==.
bysort occgb: egen percentHouses1Servant=mean(temp1servant)
bysort occgb: egen percentHousesOver1Servant=mean(tempOver1servant)
drop temp1servant tempOver1servant

replace percentHouses1Servant=percentHouses1Servant*100
replace percentHousesOver1Servant=percentHousesOver1Servant*100
format percentHouses1Servant %9.0f
format percentHousesOver1Servant %9.0f

// Only keep one observation per occupation, with mean number of servants in that occupation
bysort occgb: gen occupationID=_n
bysort occgb: egen numberHouseholds=max(occupationID)
keep if occupationID==1
drop occupationID

// Rank occupations by average number of servants
egen rank1Servant=rank(percentHouses1Servant)
egen rankOver1Servant=rank(percentHousesOver1Servant)

log on 
******************************************************************************************
** Table I: % of servants within each occupation group
******************************************************************************************
// Occupations with highest share of households with one servant
gsort - percentHouses1Servant
list occgb percentHouses1Servant percentHousesOver1Servant numberHouseholds if rank1Servant>(_N-10)

// Occupations with highest share of households with more than one servant
gsort - percentHousesOver1Servant
list occgb percentHouses1Servant  percentHousesOver1Servant numberHouseholds  if rankOver1Servant>(_N-10)

capture log close
	

	
