***************************************************************************************
** Script to calculate summary statistics and t-tests underlying Table 2 						**
***************************************************************************************
use "$datapath/Chapman_QJPS_2018analysis.dta",clear

***************************************************************************************
** Tables of characteristics pre and post matching	
***************************************************************************************
gen density1891=l3.density if financialYearEnd==1894
keep if financialYearEnd==1894

sort id financialYearEnd
local counter=0
foreach var of varlist popn1891 crowding populationGrowth density1891 pctService1881 ///
	pctAgriculture1881 pctIndustrialMining1881 pcNrateableValueComb   {
	di `counter'
	summ `var' if nonmb==1 [aweight=usedWeight] 
	local n1=`r(N)'
	local mean1=`r(mean)'
	summ `var' if nonmb==0  [aweight=usedWeight] 
	local n0=`r(N)'
	local mean0=`r(mean)'
	local diff=`mean1'-`mean0'
	ttest `var' if usedWeight==1 , by(nonmb)		
	matrix H=(`n1' , `mean1' ,`n0', `mean0' , `diff',  `r(se)')
	if `counter'==0 matrix G=H
	else matrix G=(G \ H)
	** Now without matching weights
	summ `var' if nonmb==1 
	local n1=`r(N)'
	local mean1=`r(mean)'
	summ `var' if nonmb==0 
	local n0=`r(N)'
	local mean0=`r(mean)'
	local diff=`mean1'-`mean0'
	ttest `var', by(nonmb)		
	matrix J=(`n1' , `mean1' ,`n0', `mean0' , `diff',`r(se)')
	if `counter'==0 matrix I=J
	else matrix I=(I \ J)	
	** Now without stage1
	summ `var' if nonmb==1 & excludeStage1==0
	local n1=`r(N)'
	local mean1=`r(mean)'
	summ `var' if nonmb==0 & excludeStage1==0
	local n0=`r(N)'
	local mean0=`r(mean)'
	local diff=`mean1'-`mean0'
	ttest `var' if excludeStage1==0, by(nonmb)		
	matrix L=(`n1' , `mean1' ,`n0', `mean0' , `diff',`r(se)')
	if `counter'==0 matrix K=L
	else matrix K=(K \ L)			
	local counter =`counter'+1
	di `counter'
}		

matrix rownames G= "1891 population" "Urban crowding" "Population growth" "Population density" "Occupation Service (\%)" "Occupation Agriculture (\%)" "Occupation Industrial (\%)" "Rateable Value p.c."
matrix rownames I= "1891 population" "Urban crowding" "Population growth" "Population density" "Occupation Service (\%)" "Occupation Agriculture (\%)" "Occupation Industrial (\%)" "Rateable Value p.c."
matrix rownames K= "1891 population" "Urban crowding" "Population growth" "Population density" "Occupation Service (\%)" "Occupation Agriculture (\%)" "Occupation Industrial (\%)" "Rateable Value p.c."

esttab matrix(I, fmt(0 "0 2 1 2 0 0 0 2" 0 "0 2 1 2 0 0 0 2" "0 2 1 2 2 2 2 2" "0 2 2 2 2 2 2 2")) ///	
	using "$outputpath/table2_panel1.tex", ///
replace style(tex) collabels("",none) mlabels("",none) mgroups("",none) f 

esttab matrix(K, fmt(0 "0 2 1 2 0 0 0 2" 0 "0 2 1 2 0 0 0 2" "0 2 1 2 2 2 2 2" "0 2 2 2 2 2 2 2")) ///	
	using "$outputpath/table2_panel2.tex", ///
replace style(tex) collabels("",none) mlabels("",none) mgroups("",none) f 

esttab matrix(G, fmt(0 "0 2 1 2 0 0 0 2" 0 "0 2 1 2 0 0 0 2" "0 2 2 2 2 2 2 2" "0 2 2 2 2 2 2 2")) ///	
	using "$outputpath/table2_panel3.tex", ///
replace style(tex) collabels("",none) mlabels("",none) mgroups("",none) f 
