******************************************************************************************
** Run regressions of estimating the DID equations	in Table 3 and associated appendices				**	
**																						**
** NOTE BEFORE RUNNING: 																	**
** Subset of observations used is defined by the global macro $keepGroup							**
** , the dependent variable by the macro $depvar												**
** and the control variables by $controls														**
******************************************************************************************
use "$datapath/Chapman_QJPS_2018analysis.dta",clear

******************************************************************************************
** Preliminaries: define sample 
******************************************************************************************
// Keep those without missing data to ensure same dataset across specifications
keep if forRegression==1

// Drop those not in matched sample
keep $keepGroup
******************************************************************************************

******************************************************************************************
** Regressions: store and then save results as .tex
******************************************************************************************
eststo drop *
fvset base 1 financialYearEnd

// All towns
** No controls
#delimit;
eststo: xtreg $depvar
	  nonmb_x_post1894 post1894 i.financialYearEnd
	  , robust fe;
#delimit cr	  
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "N" , replace				
estadd local fixed "Y" , replace	
	  
** With controls
#delimit;
eststo: xtreg $depvar
	  nonmb_x_post1894 post1894 i.financialYearEnd
	  $controls
	  , robust fe;
#delimit cr	  
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

// Upper-class controlled only
** No controls
#delimit;
eststo: xtreg $depvar
	  nonmb_x_post1894 post1894 i.financialYearEnd
	  if middleClassTown==0, robust fe;
#delimit cr	  
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "N" , replace				
estadd local fixed "Y" , replace	

** With controls
#delimit;
eststo: xtreg $depvar
	  nonmb_x_post1894 post1894 i.financialYearEnd
	  $controls
	  if middleClassTown==0, robust fe;
#delimit cr	  
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

// Middle-class controlled only
** No controls
#delimit;
eststo: xtreg $depvar
	  nonmb_x_post1894 post1894 i.financialYearEnd
	  if middleClassTown==1, robust fe;
#delimit cr	  
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "N" , replace				
estadd local fixed "Y" , replace	

** With controls
#delimit;
eststo: xtreg $depvar
	  nonmb_x_post1894 post1894 i.financialYearEnd
	  $controls
	  if middleClassTown==1, robust fe;
#delimit cr	  
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

if "${specification}" == "main" {
	log using "$outputpath/magnitude.text",replace
	** Estimate magnitudes referenced in text
	qui summ pcNexpCurrentTotal,d
	di -(_b[nonmb_x_post1894]*r(sd))/r(mean)
	local sd=r(sd)
	qui summ pcNexpCurrentTotal if middleClassTown==1,d
	di -(_b[nonmb_x_post1894]*`sd')/r(mean)
	cap log close
}

******************************************************************************************
** Save regression table
******************************************************************************************
if "${specification}" == "main" {
	local tableName = "Table3.tex"
}
if "${specification}" == "comparison" {
	local tableName = "app_tableC8.tex"
}

else if "${specification}" == "noNWcounties" {
	local tableName = "app_tableC11.tex"
}
else if "${specification}" == "matchAgriculture" {
	local tableName = "app_tableC12.tex"
}

else if "${specification}" == "matchIndustry" {
	local tableName = "app_tableC13.tex"
}
else if "${specification}" == "matchNo1835MBs" {
	local tableName = "app_tableC14.tex"
}
else if "${specification}" == "realValues" {
	local tableName = "app_tableC15.tex"
}
if "${specification}" == "realValues" { 
	cd "$outputpath"
	#delimit;
	esttab  using `tableName', replace label nostar 
		keep(nonmb_x_post1894  sd_pcrateableValueCombReal sd_pcrecCurrentPropertyReal sd_pcrecCurrentTransfersReal post1894)  
		order(nonmb_x_post1894  sd_pcrateableValueCombReal sd_pcrecCurrentPropertyReal sd_pcrecCurrentTransfersReal post1894) 
		cells(b(fmt(3)) se(par fmt(3))) /** starlevels(* 0.10 ** 0.05 *** 0.01)  **/ legend 	f mlabels(none) nonum collabels(none)  
		s(pop_controls financialYearEndfe fixed N, label( "Controls" "Year FE" "Town FE" "Obs." )  fmt(%9.0f %9.0f %9.0f %9.0f %9.2f %9.2f));
	#delimit cr
}
else { 
	cd "$outputpath"
	#delimit;
	esttab  using `tableName', replace label nostar 
		keep(nonmb_x_post1894  sd_pcNrateableValueComb sd_pcNrecCurrentProperty sd_pcNrecCurrentTransfersTotal post1894)  
		order(nonmb_x_post1894  sd_pcNrateableValueComb sd_pcNrecCurrentProperty sd_pcNrecCurrentTransfersTotal post1894) 
		cells(b(fmt(3)) se(par fmt(3))) /** starlevels(* 0.10 ** 0.05 *** 0.01)  **/ legend 	f mlabels(none) nonum collabels(none)  
		s(pop_controls financialYearEndfe fixed N, label( "Controls" "Year FE" "Town FE" "Obs." )  fmt(%9.0f %9.0f %9.0f %9.0f %9.2f %9.2f)); 
	#delimit cr
}

