******************************************************************************************
** Estimate dynamic specifications in Table 4																**
**																									**
**																									**
** NOTE BEFORE RUNNING: 																	**
** Control variables are defined by global macro $controls										**
*****************************************************************************************
use "$datapath/Chapman_QJPS_2018analysis.dta",clear

******************************************************************************************
** Define sample 
******************************************************************************************
// Keep those without missing data to ensure same dataset across specifications
keep if forRegression==1

// Drop those not in matched sample
keep if usedWeight==1&middleClassTown==1
******************************************************************************************

******************************************************************************************
** Regressions
******************************************************************************************
eststo drop *
fvset base 1 financialYearEnd							  

// No controls
#delimit;
eststo estNoControls: xtreg sd_pcNexpCurrentTotal dummyYear* 
	timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "N" , replace
estadd local trends "None" , replace

// Include time-varying controls	  ;
#delimit;
eststo estWithControls: xtreg sd_pcNexpCurrentTotal dummyYear*
	$controls
	timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "None" , replace

// Include linear town-specific time trends
#delimit;
eststo estLinearTrends: xtreg sd_pcNexpCurrentTotal dummyYear* 
	$controls
	individualTime_* 
	timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Linear town" , replace

// Include time trends by population
#delimit;
eststo estPopulationTrends: xtreg sd_pcNexpCurrentTotal dummyYear* 
	$controls
	time*_population* 
	timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Population" , replace

// Include time trends by density
#delimit;
eststo estDensityTrends: xtreg sd_pcNexpCurrentTotal dummyYear* 
	$controls
	time*_density* 
	timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Density" , replace

// Include time trends by population growth
#delimit;
eststo estGrowthTrends: 
	xtreg sd_pcNexpCurrentTotal dummyYear* 
	$controls
	time*_popGrowth* 
	timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Growth" , replace

// Include time trends by urban crowding
#delimit;
eststo estCrowdTrends: 
	xtreg sd_pcNexpCurrentTotal dummyYear* 
	$controls
	time*_crowd* 
	timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Crowding" , replace

// Include time trends by percentage agriculture
#delimit;
eststo estAgricTrends: 
	xtreg sd_pcNexpCurrentTotal dummyYear* 
	$controls
	time*_pctAgric* 
	timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Agriculture" , replace

// Include time trends by percentage industrial
#delimit;
eststo estIndustTrends: 
	xtreg sd_pcNexpCurrentTotal dummyYear* 
	$controls
	time*_pctIndust* 
	timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Industry" , replace

// Include time trends by rateable value
#delimit;
eststo estRateValTrends:
	xtreg sd_pcNexpCurrentTotal dummyYear* 
	$controls
	time*_pcrateVal* 
	timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Tax base" , replace

// Include time trends by loansout
#delimit;
eststo estLoansOutTrends:
	xtreg sd_pcNexpCurrentTotal dummyYear* 
	$controls
	time*_pcNoutLoansTotal*
	timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "1883 loans" , replace

******************************************************************************************
** Output 
******************************************************************************************
label var nonmb_x_post1894 "Unincorp.*post1894"
label var timeNonMBPost1894 "Unincorp.*timePost1894"
label var timeNonMBPost1896 "Unincorp.*timePost1896"

// Output table
#delimit;
esttab estWithControls estLinearTrends estDensityTrends estAgricTrends estRateValTrends estLoansOutTrends
	using  "$outputpath/Table4.tex", replace label  nostar
	keep(timeNonMBPost1894 timeNonMBPost1896)  
	order(timeNonMBPost1894 timeNonMBPost1896)  
	cells(b(fmt(3)) se(par fmt(3))) legend f mlabels(none) nonum collabels(none) 
	s(financialYearEndfe fixed controls trends jointTitle jointFstat jointFpval post1896trend post1896trendSE  N
	, label( "Year FE" "Town FE" "Controls" "Trends" "Joint significance" "~~F-stat" "~~p-value" "post-1896 trend" " "  "Obs." )  
	fmt(%9.0f %9.0f %9.0f %9.0f %9.0f %9.2f %9.3f %9.3f %9.3f %9.0f));
#delimit cr
