******************************************************************************************
** Run regressions of estimating the specifications reported in Table 5 and Table C5	 				**
**																						**
** NOTE BEFORE RUNNING: 																	**
** Control variables are defined by global macro $controls										**
*****************************************************************************************
use "$datapath/Chapman_QJPS_2018analysis.dta",clear

******************************************************************************************
** Preliminaries: define sample 
******************************************************************************************
// Keep those without missing data to ensure same dataset across specifications
keep if forRegression==1

// Drop those not in matched sample
keep if usedWeight==1&middleClassTown==1
******************************************************************************************

******************************************************************************************
** Regression results
******************************************************************************************
#delimit;
local item = "sd_pcNexpCurrentWater sd_pcNexpCurrentSewers sd_pcNexpCurrentStreet 
	 sd_pcNexpCurrentGas sd_pcNexpCurrentOtherPW sd_pcNexpCurrentLoans
	 sd_pcNrecCurrentTax sd_pcNrecCurrentTolls 
	 sd_pcNoutLoansTotal " ; 
#delimit cr

mat define results=J(10,2,.) 
mat define resultsDy=J(10,6,.) 

local c=1
// Run fixed effects specifications, first with just post-1894 then also post1896
foreach var in `item' {
	fvset base 1 financialYearEnd							  
	**Include linear town-specific time trends
	#delimit;
		eststo lin`c':xtreg `var' dummyYear* 
		individualTime_* 
		$controls
		timeNonMBPost1894 
		, vce(cluster id) fe;
	#delimit cr
	mat results[`c',1]=_b[timeNonMBPost1894]
	mat results[`c',2]=_se[timeNonMBPost1894]
	#delimit;
		eststo lin`c':xtreg `var' dummyYear* 
		individualTime_* 
		$controls
		timeNonMBPost1894 timeNonMBPost1896
		, vce(cluster id) fe;
	#delimit cr
	mat resultsDy[`c',1]=_b[timeNonMBPost1894]
	mat resultsDy[`c',2]=_se[timeNonMBPost1894]
	mat resultsDy[`c',3]=_b[timeNonMBPost1896]
	mat resultsDy[`c',4]=_se[timeNonMBPost1896]
	test timeNonMBPost1894 timeNonMBPost1896
	mat resultsDy[`c',5]=r(p)
	local c=`c'+1
}

// Run population separately so we can exclude the population control variable
#delimit;
xtreg sd_population dummyYear* 
	individualTime_* 
	$controlsNoPopn
	timeNonMBPost1894
	, vce(cluster id) fe;
#delimit cr
mat results[`c',1]=_b[timeNonMBPost1894]
mat results[`c',2]=_se[timeNonMBPost1894]

**Include linear town-specific time trends
#delimit;
xtreg sd_population dummyYear* 
	individualTime_* 
	$controlsNoPopn
	timeNonMBPost1894 timeNonMBPost1896
	, vce(cluster id) fe;
#delimit cr
mat resultsDy[`c',1]=_b[timeNonMBPost1894]
mat resultsDy[`c',2]=_se[timeNonMBPost1894]
mat resultsDy[`c',3]=_b[timeNonMBPost1896]
mat resultsDy[`c',4]=_se[timeNonMBPost1896]
test timeNonMBPost1894 timeNonMBPost1896
mat resultsDy[`c',5]=r(p)

// Matrix identifying whether to include stars
cap drop mat stars
local c = colsof(results)
local r = rowsof(results)
matrix stars = J(`r',`c',0)
forvalues i = 1/`r' {
	forvalues j = 1(2)`c' {
		local cse=`j'+1
		local t = abs(results[`i', `j'] / results[`i', `cse'])
		if `t'<. {
			matrix stars[`i', `j'] = (`t' > 1.645) + (`t' > 1.96) + (`t' > 2.33)
		}
		else {
			matrix stars[`i', `j'] = 0
		}
	}
}

// Table 5
#delimit;
frmttable using "$outputpath/Table5.tex", tex replace fragment statmat(results) sdec(3\4) substat(1)
		/** annotate(stars)**/ asymbol($^{*}$,$^{**}$,$^{***}$)  plain nocenter  hlines(01000000000)
		ctitles("","Unincorporated*timePost1894") 
		rtitles("Spending: water"\""\ "Spending: sewers"\ ""\"Spending: streets"\ ""\"Spending: gas"  \
	""\"Spending: other public goods"\ ""\"Spending: loan maintenance" \
	""\"Receipts: taxes" \ ""\"Receipts: tolls and fees" \
	""\"Loans outstanding: total"\ ""\"Town population")
	;

// Table C5 with additional specifications
#delimit;
frmttable using "$outputpath/app_tableC5.tex", tex replace fragment statmat(resultsDy) sdec(3\4) substat(1)
		/** annotate(stars)**/ asymbol($^{*}$,$^{**}$,$^{***}$)  plain nocenter  hlines(01000000000)
		ctitles("","\vtop{\hbox{\strut Unincorporated}\hbox{\strut *timePost1894}}" , 
		"\vtop{\hbox{\strut Unincorporated}\hbox{\strut *timePost1896}}" , 
		"\vtop{\hbox{\strut Joint signif.}\hbox{\strut ~(p-value)}}") 
		rtitles("Spending: water"\""\ "Spending: sewers"\ ""\"Spending: streets"\ ""\"Spending: gas"  \
	""\"Spending: other public goods"\ ""\"Spending: loan maintenance" \
	""\"Receipts: taxes" \ ""\"Receipts: tolls and fees" \
	""\"Loans outstanding: total"\ ""\"Town population")
	;
	

