*******************************************************************************************
** Graphs the breakdown of revenue for Figure B1									 			**
*******************************************************************************************
use "$datapath/Chapman_QJPS_2018analysis.dta",clear

******************************************************************************************
** Preliminaries: define sample 
******************************************************************************************
// Keep those without missing data to ensure same dataset across specifications
keep if forRegression==1

// Drop those not in matched sample
keep if usedWeight==1
******************************************************************************************
foreach i in Tax Transfers Property Fees Other {
	gen grpct`i'=pctNrecCurrent`i'
}


******************************************************************************************
// ** Collapse to get data by year and type of town for graphs
******************************************************************************************
collapse grpct*, by(financialYearEnd nonmb)

** Reshape to long so we can use the "over" command in the graph function
reshape long grpct, i(financialYearEnd nonmb) j(type) string

** Now reshape to wide so nonmb and mb are on same line
reshape wide grpct, i(financialYearEnd type) j(nonmb)

label var grpct0 "Incorporated"
label var grpct1 "Unincorporated"

replace type="Grants" if type=="Transfers"
generate order = 1 if type=="Tax"
replace order = 2 if type=="Fees"
replace order = 3 if type=="Property"
replace order = 4 if type=="Grants"
replace order = 5 if type=="Other"

** Label for graph labels
label define order 1 "Tax" 2 "Fees" 3 "Property" 4 "Grants" 5 "Other" 
label values order order

set scheme s2mono
#delimit;
gr bar grpct0 grpct1 if financialYearEnd==1884
	, over(order, label(labsize(small))) 
	ytitle(% of current revenue,size(small))
	graphregion(fcolor(white) lcolor(white) margin(l-1.5 r-1)) 
	plotr(m(1)) 
	yscale(range(0(20)80)) 
	ylabel(#5,labsize(small)) 
	legend( region(lcolor(white)) label(1 "Incorporated") label(2 "Unincorporated") size(small)) 
	name(revenueSplit1884,replace)
	title("1883-84",size(medium))
;
gr bar grpct0 grpct1 if financialYearEnd==1903
	, over(order, label(labsize(small))) 
	ytitle(% of current revenue,size(small))
	graphregion(fcolor(white) lcolor(white) margin(l-1.5 r-1)) 
	plotr(m(1)) 
	yscale(range(0(20)80))
	ylabel(#5,labsize(small)) 
	legend(region(lcolor(white)) label(1 "Incorporated") label(2 "Unincorporated") size(small)) 
	name(revenueSplit1903,replace)
	title("1902-1903",size(medium))
;
	
grc1leg  revenueSplit1884 revenueSplit1903 , graphregion(fcolor(white)  lwidth(large) lcolor(white));

#delimit cr 

gr export "$outputpath/app_figureB1.tif", replace width(3543)

