*******************************************************************************************
** Graphs the breakdown of spending for Figure B2									 			**
*******************************************************************************************
use "$datapath/Chapman_QJPS_2018analysis.dta",clear

******************************************************************************************
** Preliminaries: define sample 
******************************************************************************************
// Keep those without missing data to ensure same dataset across specifications
keep if forRegression==1

// Drop those not in matched sample
keep if usedWeight==1
******************************************************************************************

foreach i in Streets Sewers Water Gas OtherPW Loans OtherLAs Other Justice Education {
	gen grpct`i'=pctNexpCurrent`i'
}

*******************************************************************************************
// ** Collapse to get data by year and type of town for graphs
*******************************************************************************************
collapse grpct*, by(financialYearEnd nonmb)

** Reshape to long so we can use the "over" command in the graph function
reshape long grpct, i(financialYearEnd nonmb) j(type) string

** Now reshape to wide so nonmb and mb are on same line
reshape wide grpct, i(financialYearEnd type) j(nonmb)

label var grpct0 "Incorporated"
label var grpct1 "Unincorporated"

generate order = 1 if type=="Streets"
replace order = 2 if type=="Sewers"
replace order = 3 if type=="Water"
replace order = 4 if type=="Gas"
replace order = 5 if type=="OtherPW"
replace order = 6 if type=="Loans"
replace order = 7 if type=="OtherLAs"
replace order = 8 if type=="Other"
replace order = 9 if type=="Justice"
replace order = 10 if type=="Education"

** Label for graph labels
label define order 1 "Streets" 2 "Sewers" 3 "Water" 4 "Gas" 5 "Other Public Goods" ///
	6 "Loan Service" 7 "Other LAs" 8 "Other" 9 "Justice system" 10 "Education"
label values order order

set scheme s2mono
#delimit;
gr bar grpct0 grpct1 if financialYearEnd==1884,
	over(order, label(labsize(vsmall)) 
	relabel( 5 `" "Other" "public" "goods"  "'  6 `" "Loan" "Service" "' 7 `" "Other" "LAs" "' 9 `" " " "Justice" "System" "')) 
	graphregion(margin(l-1.5 r-1) fcolor(white) lcolor(white)) 
	plotr(m(1)) 
	ytitle(% of current expenditure,size(small)) 
	graphregion() 
	yscale(range(0(10)40)) 
	ylabel(#5,labsize(small))  
	legend(region(lcolor(white)) label(1 "Incorporated") label(2 "Unincorporated") size(small)) 
	name(spendSplit1884,replace) 
	title("1883-84",size(medium))
; 

gr bar grpct0 grpct1 if financialYearEnd==1903,
	over(order, label(labsize(vsmall)) 
	relabel( 5 `" "Other" "public" "goods"  "'  6 `" "Loan" "Service" "' 7 `" "Other" "LAs" "' 9 `" " " "Justice" "System" "')) 
	graphregion(margin(l-1.5 r-1) fcolor(white) lcolor(white)) 
	plotr(m(1)) 
	ytitle(% of current expenditure,size(small)) 
	yscale(range(0(10)40))
	ylabel(#5,labsize(small))   
	legend(region(lcolor(white)) label(1 "Incorporated") label(2 "Unincorporated") size(small)) 
	name(spendSplit1903,replace) 
	title("1902-03",size(medium))
;
#delimit cr	

// Combine graphs and export
grc1leg  spendSplit1884 spendSplit1903 , graphregion(fcolor(white) lwidth(large) lcolor(white)) 

gr export "$outputpath/app_figureB2.tif", replace width(3543)



