**************************************************************************
** Script to use data from US Commissioner of Labor to estimate price elasticities	**
** in later 1890s															**
** Author: Jonathan Chapman												**
**************************************************************************

**********************************************************************
** Need to install renvars

**********************************************************************
// Data from ???

use "$datapath/ICPSR_07711/DS0001/USCLcostOfLiving07711-0001-Data.dta", clear

// Only keep British data
keep if RESID==34 

// Adjust into GBP using Exchange rate taken from "THe UK-recession in context - what do three centuries of data tell us"  - in order to use poverty lines from rowntree
foreach var of varlist   TOTALINC  HUSINC WIFINC KIDINC BORDINC OTHERINC NATLWAGE FOODEXP RENT2 OTHEREXP TOTALEXP BEEF PORK MEAT EGGS LARD BUTTER TEA COFFEE SUGAR MOLASSES POTATOES POULTRY FISH MILK FLOUR BREAD RICE CHEESE FRUIT CONDIMEN VEGS FOODOTH FOODEXP2 RENT FUELEXP LIGHTEXP HUSCLOTH WIFCLOTH FURNTURE KIDCLOTH TAXES PROPINS LIFEINS READING AMUSVAC LIQUOR TOBACCO SICKNESS LABOREXP ORGEXP RELIG CHARITY OTHEXP2 LOCLWAGE  {
	replace `var' = (`var'/4.86)*20/52 
}

renvars *,lower

// Combine categories of expenditures
gen liqtobac=liquor+tobacco
egen basics=rowtotal(butter bread condimen flour lard potatoes rice tea foodoth)
egen cheesemilk=rowtotal(cheese milk )
egen meatfish=rowtotal(fish meat pork poultry)
egen fruitveg=rowtotal(fruit vegs )
egen luxury=rowtotal(eggs coffee sugar molasses )
egen nonbasics=rowtotal(luxury fruitveg meatfish cheesemilk)
egen clothing=rowtotal(huscloth wifcloth kidcloth)
egen amusements=rowtotal(reading amusvac)
egen fun=rowtotal(liqtobac reading amusvac)
egen lightfuel=rowtotal(fuelexp lightexp)
egen otherspend =rowtotal(laborexp orgexp relig charity taxes propins lifeins sickness othexp2 furnture)

// Number of adults and saving
gen no_adults=hhsize-kidtot
gen savings=totalinc-totalexp

foreach var of varlist basics cheesemilk  meatfish fruitveg luxury liqtobac clothing amusements lightfuel otherspend nonbasics fun foodexp rent savings furnture {
	gen share_`var'=`var'/totalinc 
}

// Identify poverty line using Rowntree line adjusted from equivalence scales in Gazeley and Newell (2000), Tables 2 and 3
gen poverty=11*12+8 if no_adults==2&kidtot==0
replace poverty= (11*12+8)*1.19 if no_adults==2&kidtot==1
replace poverty= (11*12+8)*1.45 if no_adults==2&kidtot==2
replace poverty= (11*12+8)*1.67 if no_adults==2&kidtot==3
replace poverty= (11*12+8)*1.84 if no_adults==2&kidtot==4
replace poverty= (11*12+8)*1.97 if no_adults==2&kidtot==5
replace poverty= (11*12+8)*2.07 if no_adults==2&kidtot==6

// Convert poverty lines into monthly income and generate ratio
gen poverty2=poverty/12
gen ratio=totalinc/poverty2

// Binary variable identifying if in debt
gen debt=1 if savings<0
replace debt=0 if savings>=0&savings<.

// Output log file with table
capture log close
log using  "$outputpath/app_table7", replace text

// First 1.25x the poverty line
capture drop inc
gen inc=1 if ratio<1.25

summ share_basics share_nonbasics share_foodexp share_rent share_clothing share_lightfuel share_amusements share_liqtobac share_otherspend share_savings debt if inc==1

// Second 1.5x the poverty line
capture drop inc
gen inc=1 if ratio<=1.5
summ share_basics share_nonbasics share_foodexp share_rent share_clothing share_lightfuel share_amusements share_liqtobac share_otherspend share_savings debt if inc==1

// Third 2x the poverty line
capture drop inc
gen inc=1 if ratio<=2
summ share_basics share_nonbasics share_foodexp share_rent share_clothing share_lightfuel share_amusements share_liqtobac share_otherspend share_savings debt if inc==1

log close

