******************************************************************************************
** Identifies pattern of starting investment in towns before incorporation 							**
** reported in Appendix Table B1	 															**
******************************************************************************************
use "$datapath/Chapman_QJPS_2018expanded.dta",clear

// Use those incorporated between 1872 and 1894
keep if incorporationDate>=1872&incorporationDate<=1894

//** For water and sewers use year first appear in spending 
foreach x in Water Sewers {
	gen involved`x'=1 if NexpTotal`x'>0 &NexpTotal`x'<.
	tempvar temp1
	gen temp1=financialYearEnd if involved`x'==1
	bysort id: egen firstYear`x'=min(temp1)
	drop temp1
	gen involvedBeforeIncorp`x'=1 if firstYear`x'<=incorporationDate
	replace involvedBeforeIncorp`x'=2 if firstYear`x'>incorporationDate&firstYear`x'<=1900
	replace involvedBeforeIncorp`x'=3 if firstYear`x'>1900
	label values involvedBeforeIncorp`x' spendingStart
}

// For other types use data from Parliamentary report 
foreach i in Bath Burial Gas Markets { 
	gen `i'Start=1 if dateStarted`i'<=incorporationDate
	replace `i'Start=2 if dateStarted`i'>incorporationDate&dateStarted`i'<.
	replace `i'Start=3 if dateStarted`i'==.
	label values `i'Start spendingStart
}


******************************************************************************************
// Output for appendix Table 5
******************************************************************************************
log using "$outputpath/app_tableB1",text replace
tab BathStart if financialYearEnd==1894
tab BurialStart if financialYearEnd==1894
tab GasStart if financialYearEnd==1894
tab MarketsStart if financialYearEnd==1894
tab involvedBeforeIncorpSewers if financialYearEnd==1894
tab involvedBeforeIncorpWater if financialYearEnd==1894

log close

