*******************************************************************************************
** Run regressions controlling for poor law spending, reported in Table XXX	 **
** Subset of observations used is defined by the global macro $keepGroup							 **
** and the control variables by $controls														 **
*******************************************************************************************
use "$datapath/Chapman_QJPS_2018analysis.dta",clear

******************************************************************************************
** Preliminaries: define sample 
******************************************************************************************
// Keep those without missing data to ensure same dataset across specifications
keep if forRegression==1

// Drop those not in matched sample
keep if usedWeight==1
******************************************************************************************

******************************************************************************************
** Regressions
******************************************************************************************
// Variable labels
label var nonmb "Unincorporated"
label var nonmb_x_post1894 "Unincorporated*post1894"
label var post1894 "post1894"
label var sd_poorRatePerCapita 		   "Poor rate p.c."
label var sd_poorRatePerCapitaAdjusted "Poor rate p.c., adjusted"
label var sd_pauperReliefPerCapita "Poor relief p.c."

eststo drop * 
// First all towns
** With all poor rates
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd 
	$controls
	sd_poorRatePerCapita
	,robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local fin_controls "Y" , replace				
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

** With adjusted poor rates
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd 
	$controls
	sd_poorRatePerCapitaAdjusted  
	,robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local fin_controls "Y" , replace				
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

** With poor relief
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd
	$controls
	sd_pauperReliefPerCapita 
	,robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local fin_controls "Y" , replace				
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

// Now upper class only
** With all poor rates
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd
	$controls
	sd_poorRatePerCapita
	if middleClassTown==0,robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local fin_controls "Y" , replace				
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

** With adjusted poor rates
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd 
	$controls
	sd_poorRatePerCapitaAdjusted 
	if middleClassTown==0,robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local fin_controls "Y" , replace				
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

** With poor relief
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd 
	$controls
	sd_pauperReliefPerCapita  
	if middleClassTown==0,robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local fin_controls "Y" , replace				
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

// Now middle class only
** With all poor rates
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd 
	$controls
	sd_poorRatePerCapita 
	if middleClassTown==1,robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local fin_controls "Y" , replace				
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

** With adjusted poor rates
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd 
	$controls
	sd_poorRatePerCapitaAdjusted
	if middleClassTown==1,robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local fin_controls "Y" , replace				
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

** With poor relief
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd 
	$controls
	sd_pauperReliefPerCapita 
	if middleClassTown==1,robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local fin_controls "Y" , replace				
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

******************************************************************************************
** Output
******************************************************************************************
cd "$outputpath"
#delimit;
esttab  using app_tableC10.tex, replace label nostar 
	keep(nonmb_x_post1894 post1894 sd_poorRatePerCapita sd_poorRatePerCapitaAdjusted sd_pauperReliefPerCapita )  
	order(nonmb_x_post1894 post1894 sd_poorRatePerCapita sd_poorRatePerCapitaAdjusted sd_pauperReliefPerCapita)  
	cells(b(fmt(3)) se(par fmt(3))) /** starlevels(* 0.10 ** 0.05 *** 0.01)  **/ legend 	f mlabels(none) nonum collabels(none)  
	s(pop_controls financialYearEndfe fixed N, label( "Controls" "Year FE" "Town FE" "Obs." )  fmt(%9.0f %9.0f %9.0f %9.0f %9.0f));
#delimit cr
