******************************************************************************************
** Produces descriptive statistics reported in Table C3			 			 								**
** the descriptive stats of the variables used in the regressions	 											**
** Need to install sutex2									 											**
******************************************************************************************
// Use regression dataset, then merge in original data for density 
// so we can use 1881 year 
// In main regressions use categorical variables, but display actual values here
use "$datapath/Chapman_QJPS_2018analysis.dta",clear
drop density 
merge 1:1 id financialYearEnd using "$datapath/Chapman_QJPS_2018expanded.dta",keepusing(density)
sort id financialYearEnd
replace density=l3.density if financialYearEnd==1884 
replace crowding=l1.crowding if financialYearEnd==1902
replace crowding=l2.crowding if financialYearEnd==1903

******************************************************************************************
** Preliminaries: define sample 
******************************************************************************************
// Keep those without missing data to ensure same dataset across specifications
keep if forRegression==1

// Drop those not in matched sample
keep if usedWeight==1
******************************************************************************************

******************************************************************************************
// Label and generate temporary variables	
******************************************************************************************
gen populationTemp=population/1000
label var pcNexpCurrentTotal "Current spending per capita (\pounds p.c.)"
label var pcNoutLoansTotal	"Loans outstanding per capita (\pounds p.c.)"
label var pcNrecCurrentTax "Tax receipts (\pounds p.c.)"
label var pcNrecCurrentProperty "Property receipts (\pounds p.c.)"
label var pcNrecCurrentTransfers "Grant receipts (\pounds p.c.)"
label var populationTemp "Population ('000s)"
label var crowding  "Crowding (Population/number of houses)"
label var populationGrowth "Population growth (\%)"
label var pcNrateableValueComb  	"Tax base per capita (\pounds p.c.)"
label var pctIndustrial1881		  		"\% Workforce in industry/mining"
label var density				"Population density"

******************************************************************************************
// Save file 
******************************************************************************************
cd "$outputpath"
#delimit;
sutex2 pcNexpCurrentTotal pcNoutLoansTotal pcNrateableValueComb  
	pcNrecCurrentProperty pcNrecCurrentTransfers 
	populationTemp populationGrowth
	crowding density
	, minmax varlabels  tabular saving("app_tableC3.tex") replace digits(2) nocheck
;
