******************************************************************************************
** Run regressions of estimating the dynamic DID equations												**
** in Appendix tables C4 and C9																		**
**																									**
** NOTE BEFORE RUNNING: 																			**
** Dependent variable is controlled by global macro $depvar													**
** and the control variables by $controls																	**
******************************************************************************************
use "$datapath/Chapman_QJPS_2018analysis.dta",clear

******************************************************************************************
** Define sample 
******************************************************************************************
// Keep those without missing data to ensure same dataset across specifications
keep if forRegression==1

// Drop those not in matched sample
keep if usedWeight==1&middleClassTown==1
******************************************************************************************

******************************************************************************************
** Regressions
******************************************************************************************
eststo drop *
fvset base 1 financialYearEnd							  

// No controls
#delimit;
eststo estNoControls: xtreg $depvar dummyYear* 
	timeNonMBPost1883 timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "N" , replace
estadd local trends "None" , replace

// Include time-varying controls	  ;
#delimit;
eststo estWithControls: xtreg $depvar dummyYear*
	$controls
	timeNonMBPost1883 timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "None" , replace

// Include linear town-specific time trends
#delimit;
eststo estLinearTrends: xtreg $depvar dummyYear* 
	$controls
	individualTime_* 
	timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Linear town" , replace


// Include time trends by population
#delimit;
eststo estPopulationTrends: xtreg $depvar dummyYear* 
	$controls
	time*_population_* 
	timeNonMBPost1883 timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
di `roundedSE'
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Population" , replace

// Include time trends by density
#delimit;
eststo estDensityTrends: xtreg $depvar dummyYear* 
	$controls
	time*_density_* 
	timeNonMBPost1883 timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Density" , replace

// Include time trends by population growth
#delimit;
eststo estGrowthTrends: 
	xtreg $depvar dummyYear* 
	$controls
	time*_popGrowth_* 
	timeNonMBPost1883 timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Growth" , replace

// Include time trends by urban crowding
#delimit;
eststo estCrowdTrends: 
	xtreg $depvar dummyYear* 
	$controls
	time*_crowd_* 
	timeNonMBPost1883 timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Crowding" , replace


// Include time trends by percentage agriculture
#delimit;
eststo estAgricTrends: 
	xtreg $depvar dummyYear* 
	$controls
	time*_pctAgric* 
	timeNonMBPost1883 timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Agriculture" , replace


// Include time trends by percentage industrial
#delimit;
eststo estIndustTrends: 
	xtreg $depvar dummyYear* 
	$controls
	time*_pctIndust* 
	timeNonMBPost1883 timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Industry" , replace

// Include time trends by rateable value
#delimit;
eststo estRateValTrends:
	xtreg $depvar dummyYear* 
	$controls
	time*_pcrateVal* 
	timeNonMBPost1883 timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "Tax base" , replace

// Include time trends by loansout
#delimit;
eststo estLoansOutTrends:
	xtreg $depvar dummyYear* 
	$controls
	time*_pcNoutLoansTotal*
	timeNonMBPost1883 timeNonMBPost1894 timeNonMBPost1896 
	, vce(cluster id) fe;
#delimit cr			
test timeNonMBPost1894 timeNonMBPost1896 
estadd local jointTitle "", replace
estadd scalar jointFstat=r(F), replace
estadd scalar jointFpval=r(p), replace
lincom timeNonMBPost1894+timeNonMBPost1896
local roundedSE: display %9.3f r(se)
estadd scalar post1896trend=r(estimate), replace
estadd local  post1896trendSE="("+string(r(se),"%9.3f")+")", replace
estadd local financialYearEndfe "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
estadd local trends "1883 loans" , replace


******************************************************************************************
** Export results
******************************************************************************************
label var nonmb_x_post1894 "Unincorp.*post1894"
label var timeNonMBPost1883 "Unincorp.*timePost1883"
label var timeNonMBPost1894 "Unincorp.*timePost1894"
label var timeNonMBPost1896 "Unincorp.*timePost1896"

if "${specification}" == "middleClass" {
	local tableName = "app_tableC4.tex"
}
if "${specification}" == "comparison" {
		local tableName = "app_tableC9.tex"
}		
	
// Save table
#delimit;
esttab estWithControls estLinearTrends estDensityTrends estAgricTrends estRateValTrends estLoansOutTrends estPopulationTrends estGrowthTrends estCrowdTrends estIndustTrends using  "$outputpath/`tableName'", replace label nostar 
	keep(timeNonMBPost1883 timeNonMBPost1894 timeNonMBPost1896 )  
	order(timeNonMBPost1894 timeNonMBPost1896 timeNonMBPost1883)  
	cells(b(fmt(3)) se(par fmt(3))) legend 	f mlabels(none) nonum collabels(none)  
	s(financialYearEndfe fixed controls trends jointTitle jointFstat jointFpval post1896trend post1896trendSE  N, label( "Year FE" "Town FE" "Controls" "Trends" "Joint significance" "~~F-stat" "~~p-value" "post-1896 trend" " "  "Obs." )  
			fmt(%9.0f %9.0f %9.0f %9.0f %9.0f %9.2f %9.3f %9.3f %9.3f %9.0f));
#delimit cr	
	
	
