******************************************************************************************
** Re-estimates the main regressions using the alternative definitions of 									**	
** middle class power for Appendix Table C.6																**

** NOTE BEFORE RUNNING: 																	**
** Control variables are defined by global macro $controls										**
*****************************************************************************************
use "$datapath/Chapman_QJPS_2018analysis.dta",clear

******************************************************************************************
** Preliminaries: define sample 
******************************************************************************************
// Keep those without missing data to ensure same dataset across specifications
keep if forRegression==1

// Drop those not in matched sample
keep if usedWeight==1
******************************************************************************************
	
******************************************************************************************
** 	Regressions
******************************************************************************************
// First the second middle class definition: two upper-class , then  middle-class
eststo drop *
fvset base 1 financialYearEnd
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
		nonmb_x_post1894 post1894 i.financialYearEnd 
		if middleClassTownDefn2==0
		, robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "N" , replace				
estadd local fixed "Y" , replace	

#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd 
	$controls
	if middleClassTownDefn2==0
	, robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

#delimit;	
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd 
	if middleClassTownDefn2==1
	, robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "N" , replace				
estadd local fixed "Y" , replace

#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd 
	$controls
	if middleClassTownDefn2==1
	, robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

// Third middle class definition: two upper-class , then  middle-class
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal ///
	nonmb_x_post1894 post1894 i.financialYearEnd ///
	if middleClassTownDefn3==0
	, robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "N" , replace				
estadd local fixed "Y" , replace	

#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd 
	$controls
	if middleClassTownDefn3==0
	, robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	
	
#delimit;	
eststo: xtreg sd_pcNexpCurrentTotal
	nonmb_x_post1894 post1894 i.financialYearEnd 
	if middleClassTownDefn3==1
	, robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "N" , replace				
estadd local fixed "Y" , replace

#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894 post1894 i.financialYearEnd
	$controls
	if middleClassTownDefn3==1
	, robust fe;
#delimit cr
estadd local financialYearEndfe "Y" , replace
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

******************************************************************************************
** Output
******************************************************************************************
#delimit;
esttab  using  "$outputpath/app_tableC6.tex", replace label  
	keep(nonmb_x_post1894  sd_pcNrateableValueComb sd_pcNrecCurrentProperty sd_pcNrecCurrentTransfersTotal post1894)  
	order(nonmb_x_post1894  sd_pcNrateableValueComb sd_pcNrecCurrentProperty sd_pcNrecCurrentTransfersTotal post1894) 
	cells(b(fmt(3)) se(par fmt(3))) nostar legend 	f mlabels(none) nonum collabels(none)  
	s(pop_controls financialYearEndfe fixed N
	, label( "Controls" "Year FE" "Town FE" "Obs." )  fmt(%9.0f %9.0f %9.0f %9.0f %9.2f %9.2f))
; 
