*******************************************************************************************
** Run specifications reported in Table C7																 **
**																						**
** NOTE BEFORE RUNNING: 																	**
** Control variables are defined by global macro $controls										**
*****************************************************************************************
use "$datapath/Chapman_QJPS_2018analysis.dta",clear

******************************************************************************************
** Preliminaries: define sample 
******************************************************************************************
// Keep those without missing data to ensure same dataset across specifications
keep if forRegression==1

// Drop those not in matched sample
keep if usedWeight==1

******************************************************************************************
** Regressions
******************************************************************************************
eststo drop *
fvset base 1 financialYearEnd

// Correlation between middle class and industrial characteristics
pwcorr middleClassPowerRatio1881 pctAgriculture pctIndustrial1881 pctIndustrialMining1881
  
// Test for MC effect as interaction
#delimit; 	
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894_x_MC nonmb_x_post1894_x_UC post1894 post1894_x_MC  
	i.financialYearEnd, robust  fe;
#delimit cr
estadd local yearFE "Y" , replace
estadd local pop_controls "N" , replace				
estadd local fixed "Y" , replace	

#delimit; 	
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894_x_MC nonmb_x_post1894_x_UC post1894 post1894_x_MC 
	$controls
	i.financialYearEnd, robust  fe;	
#delimit cr	
estadd local yearFE "Y" , replace
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

// Allow for differences according to agricultural / non-agricultural town
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894_x_MC nonmb_x_post1894_x_UC nonmb_x_post1894_x_agric post1894 post1894_x_agric post1894_x_MC   
	i.financialYearEnd , robust  fe	;
#delimit cr	
estadd local yearFE "Y" , replace
estadd local pop_controls "N" , replace				
estadd local fixed "Y" , replace	

#delimit;	
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894_x_MC nonmb_x_post1894_x_UC nonmb_x_post1894_x_agric post1894 post1894_x_agric post1894_x_MC
	$controls
	i.financialYearEnd , robust  fe	;
#delimit cr
estadd local yearFE "Y" , replace
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	

// Allow for differences according to industrial / non-industrial town	
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894_x_MC nonmb_x_post1894_x_UC nonmb_x_post1894_x_indust post1894 post1894_x_indust post1894_x_MC 
	i.financialYearEnd , robust  fe	;
#delimit cr	
estadd local yearFE "Y" , replace
estadd local pop_controls "N" , replace				
estadd local fixed "Y" , replace	

#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894_x_MC nonmb_x_post1894_x_UC nonmb_x_post1894_x_indust post1894 post1894_x_indust post1894_x_MC    
	$controls
	i.financialYearEnd , robust  fe;
#delimit cr	
estadd local yearFE "Y" , replace
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	
	
// Now include agricultural and industrial	
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894_x_MC nonmb_x_post1894_x_UC 
	nonmb_x_post1894_x_indust post1894_x_indust
	nonmb_x_post1894_x_agric post1894_x_agric
	post1894 post1894_x_MC  
	i.financialYearEnd , robust  fe;
#delimit cr
estadd local yearFE "Y" , replace
estadd local pop_controls "N" , replace				
estadd local fixed "Y" , replace	
	
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894_x_MC nonmb_x_post1894_x_UC 
	nonmb_x_post1894_x_indust post1894_x_indust
	nonmb_x_post1894_x_agric post1894_x_agric
	post1894 post1894_x_MC  
	$controls
	i.financialYearEnd , robust  fe;
#delimit cr
estadd local yearFE "Y" , replace
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace		

// Allow for differences according to dense/ non-dense
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894_x_MC nonmb_x_post1894_x_UC nonmb_x_post1894_x_dense post1894 post1894_x_dense post1894_x_MC    
	i.financialYearEnd , robust  fe;	
#delimit cr
estadd local yearFE "Y" , replace
estadd local pop_controls "N" , replace				
estadd local fixed "Y" , replace	
	
#delimit;
eststo: xtreg sd_pcNexpCurrentTotal 
	nonmb_x_post1894_x_MC nonmb_x_post1894_x_UC nonmb_x_post1894_x_dense post1894 post1894_x_dense post1894_x_MC   
	$controls
	i.financialYearEnd , robust  fe	;
#delimit cr
estadd local yearFE "Y" , replace
estadd local pop_controls "Y" , replace				
estadd local fixed "Y" , replace	
	
******************************************************************************************
** Output
******************************************************************************************	
#delimit;
esttab  using  "$outputpath/app_tableC7.tex", 
	replace label 
	keep(nonmb_x_post1894_x_MC nonmb_x_post1894_x_UC nonmb_x_post1894_x_agric post1894_x_agric 
	nonmb_x_post1894_x_indust post1894_x_indust post1894 post1894_x_MC nonmb_x_post1894_x_dense post1894_x_dense)  
	order(nonmb_x_post1894_x_MC nonmb_x_post1894_x_UC nonmb_x_post1894_x_agric  
	nonmb_x_post1894_x_indust post1894 post1894_x_MC post1894_x_agric post1894_x_indust 
	nonmb_x_post1894_x_dense post1894_x_dense)  
	cells(b(fmt(3)) se(par fmt(3))) 
	nostar legend 	f mlabels(none) nonum collabels(none)  
	s(pop_controls yearFE fixed N
	, label( "Controls" "Year FE" "Town FE" "Obs." )  
	fmt(%9.0f %9.0f %9.0f %9.0f)) 
;

#delimit cr
