***************************************************************
** This file runs the matching exercise and generates variables identifying **
** matched towns under different matching procedures				
***************************************************************
use "$datapath/Chapman_QJPS_2018expanded.dta",clear

******************************************************************************************************************************
// 1) MATCHING.  First identify towns that are either CBs or incorporated before 1883 (stage 1)
// then perform 4 matching exercises (main + 3 robustness tests in appendix) and generate variables to identify whether matched or not
******************************************************************************************************************************
// Identify and drop towns that are either CBs or incorporated before 1883
gen temp=1 if financialYearEnd==1883&nonmb==0&mbusa==1
bysort id: egen mbusa_1883=max(temp)  /** Whether incorporated with sanitary authority in 1883 **/
gen excludeStage1=~(((incorporationDate<1883&mbusa_1883==1)|incorporationDate==.) & everCB==0)
label var excludeStage1 "Indicator: =1 if County boroughs or towns incorporated after 1883"
drop temp mbusa_1883

******************************************************************************************************************************
*** CEM: matching for use in main paper
******************************************************************************************************************************
tempfile temp1	/** CEM procedure emerges in a different file, so save a temporary file then merge back in **/
save `temp1'

// Drop large towns and create variables we will use
drop if excludeStage1==1
sort id financialYearEnd

gen lagdensity=l2.density			
keep if financialYearEnd==1893 
** Categorical variables based on 1893 characteristics	
xtile catLagDensity=lagdensity, nquantiles(4)
xtile catPcNRateableValueComb=pcNrateableValueComb, nquantiles(4)
xtile catPctService=pctService1881, nquantiles(2)

cem  catPcNRateableValueComb(1.5 2.5 3.5) catLagDensity(1.5 2.5 3.5)  catPctService(1.5) popn1891(1000 20000) ///
	, treat(nonmb) 
keep id financialYearEnd cem_* 
merge 1:1 id financialYearEnd using `temp1'

bysort id: egen cemMatched=max(cem_matched)
rename cemMatched usedWeight 
label var usedWeight  "Indicator: =1 if Matched in CEM for main results"
drop _merge cem_matched cem_weight cem_strata
replace usedWeight=0 if usedWeight==.

******************************************************************************************************************************
*** CEM: matching variable matching on % agriculture instead of service
******************************************************************************************************************************
tempfile temp1	 /** CEM procedure emerges in a different file, so save a temporary file then merge back in **/
save `temp1'

// Drop large towns and create variables we will use
drop if excludeStage1==1
sort id financialYearEnd
gen lagdensity=l2.density			
keep if financialYearEnd==1893 
** Categorical variables based on 1893 characteristics	
xtile catLagDensity=lagdensity, nquantiles(4)
xtile catPcNRateableValueComb=pcNrateableValueComb, nquantiles(4)
xtile catPctAgric=pctAgriculture1881, nquantiles(2)

cem  catPcNRateableValueComb(1.5 2.5 3.5) catLagDensity(1.5 2.5 3.5)  catPctAgric(1.5) popn1891(1000 20000) ///
	, treat(nonmb) 
keep id financialYearEnd cem_* 
merge 1:1 id financialYearEnd using `temp1'

bysort id: egen cemMatched=max(cem_matched)
rename cemMatched usedWeightMatchAgric
label var usedWeightMatchAgric "Indicator: =1 if Matched in CEM using % in agriculture"
drop _merge cem_matched cem_weight cem_strata
replace usedWeightMatchAgric=0 if usedWeightMatchAgric==.

******************************************************************************************************************************
*** CEM: matching variable matching on % industry instead of service
******************************************************************************************************************************
tempfile temp1	 /** CEM procedure emerges in a different file, so save a temporary file then merge back in **/
tempfile temp1	
save `temp1'

// Drop large towns and create variables we will use
drop if excludeStage1==1
sort id financialYearEnd

gen lagdensity=l2.density			
keep if financialYearEnd==1893 
** Categorical variables based on 1893 characteristics	
xtile catLagDensity=lagdensity, nquantiles(4)
xtile catPcNRateableValueComb=pcNrateableValueComb, nquantiles(4)
xtile catPctIndustry=pctIndustrialMining1881, nquantiles(2)

cem  catPcNRateableValueComb(1.5 2.5 3.5) catLagDensity(1.5 2.5 3.5)  catPctIndustry(1.5) popn1891(1000 20000) ///
	, treat(nonmb) 
keep id financialYearEnd cem_* 
merge 1:1 id financialYearEnd using `temp1'

bysort id: egen cemMatched=max(cem_matched)
rename cemMatched usedWeightMatchIndustry
label var usedWeightMatchIndustry "Indicator: =1 if Matched in CEM using % in agriculture"
drop _merge cem_matched cem_weight cem_strata
replace usedWeightMatchIndustry=0 if usedWeightMatchIndustry==.

******************************************************************************************************************************
*** CEM: matching variable excluding all post-1835 MBs
******************************************************************************************************************************
** The cem procedure emerges in a different file, so save a temporary file then merge back in
tempfile temp1	
save `temp1'

// Drop large towns and create variables we will use
drop if excludeStage1==1|(incorporationDate>1835&incorporationDate<.)
sort id financialYearEnd

gen lagdensity=l2.density			
keep if financialYearEnd==1893 
** Categorical variables based on 1893 characteristics	
xtile catLagDensity=lagdensity, nquantiles(4)
xtile catPcNRateableValueComb=pcNrateableValueComb, nquantiles(4)
xtile catPctService=pctService1881, nquantiles(2)

cem  catPcNRateableValueComb(1.5 2.5 3.5) catLagDensity(1.5 2.5 3.5)  catPctService(1.5) popn1891(1000 20000) ///
	, treat(nonmb) 
keep id financialYearEnd cem_* 
merge 1:1 id financialYearEnd using `temp1'

bysort id: egen cemMatched=max(cem_matched)
rename cemMatched usedWeight1835MBs
label var usedWeight1835MBs "Indicator: =1 if Matched in CEM excluding all post-1835 MBs"
drop _merge cem_matched cem_weight cem_strata
replace usedWeight1835MBs=0 if usedWeight1835MBs==.

******************************************************************************************************************************
// 2) VARIABLE TRANSFORM. 
// Create variables for regression
******************************************************************************************************************************
// Middle class ratio: defined only for those not excluded in stage 1
** First As % of servant houses controlled by MidClass (1 servant).  
gen middleClassPowerRatio1881=(pctHouses1Servants-(1-pctHouses0Servant-pctHouses1Servants))/(1-pctHouses0Servant)
**% servants in one-servant households as % of all servants
gen middleClassPowerRatio1881Defn2=pctServants1
** % of servant houses controlled by MidClass (1 or 2 servants)
gen middleClassPowerRatio1881Defn3=(pctHouses1Servants+pctHouses2Servants-(1-pctHouses0Servant-pctHouses1Servants-pctHouses2Servants))/(1-pctHouses0Servant) 

// Spread over all years and generate binary variables 
foreach var of varlist middleClassPowerRatio1881 middleClassPowerRatio1881Defn2 middleClassPowerRatio1881Defn3 {
	gen temp=`var' if financialYearEnd==1881 &excludeStage1==0
	xtile T`var'=temp,nq(2)
	replace T`var'=T`var'-1
	drop temp
	bysort id: egen temp=max(`var')
	drop `var'
	rename temp `var'
	replace `var'=100* `var' 
	bysort id: egen temp=max(T`var')
	drop T`var'
	rename temp T`var'
}	
	
label var middleClassPowerRatio1881 "1881 relative power of middle class (measured as % of servant houses with 1 servant)"
label var middleClassPowerRatio1881Defn2 "1881 relative power of middle class (measured as % of servants in houses with 1 servant)"
label var middleClassPowerRatio1881Defn3 "1881 relative power of middle class (measured as % of servants in houses with 1-2 servants)"

rename TmiddleClassPowerRatio1881 middleClassTown
label var middleClassTown "Indicator:=1 if above median of middle class towns (towns included after stage 1 only)"
rename TmiddleClassPowerRatio1881Defn2 middleClassTownDefn2
label var middleClassTownDefn2 "Indicator:=1 if above median of middle class towns on definition 2 (towns included after stage 1 only)"
rename TmiddleClassPowerRatio1881Defn3 middleClassTownDefn3
label var middleClassTownDefn3 "Indicator:=1 if above median of middle class towns on definition 3 (towns included after stage 1 only)"

drop pctHouses* pctServants

// Generate per capita spending, receipts and loan variables
foreach var of varlist NrecCurrent* NexpCurrent* NoutLoans* NexpTotal* {
		local l`var' : variable label `var'
		gen pc`var'=`var'/population
		label var pc`var' "`l`var'' (per capita)"
}
	
** Generate comparable spending variable
egen pcNexpCurrentComparison=rowtotal(pcNexpCurrentWater pcNexpCurrentStreet pcNexpCurrentSewers ///
	pcNexpCurrentGas pcNexpCurrentOtherPW pcNexpCurrentLoans),m
label var pcNexpCurrentComparison "Per capita spending in comparable categories"
   

// Split demographic variables into quartiles for use as control variables
foreach var of varlist populationGrowth crowding density population {
	xtile cat_`var' =`var' , n(4)
	label var cat_`var' "Quartiles of `var'"
}

// Some inconsistency in the area values across censuses (because of treatment of water etc)
// So just use the categorical variables in between census years
sort id financialYearEnd
replace cat_density=l1.cat_density if (financialYearEnd==1882|financialYearEnd==1892|financialYearEnd==1902)
replace cat_density=l2.cat_density if (financialYearEnd==1883|financialYearEnd==1893|financialYearEnd==1903)
replace cat_density=l3.cat_density if (financialYearEnd==1884|financialYearEnd==1894|financialYearEnd==1904)
replace cat_density=l4.cat_density if (financialYearEnd==1885|financialYearEnd==1895|financialYearEnd==1905)
replace cat_density=l5.cat_density if (financialYearEnd==1886|financialYearEnd==1896|financialYearEnd==1906)
replace cat_density=f4.cat_density if (financialYearEnd==1877|financialYearEnd==1887|financialYearEnd==1897|financialYearEnd==1907)
replace cat_density=f3.cat_density if (financialYearEnd==1878|financialYearEnd==1888|financialYearEnd==1898|financialYearEnd==1908)
replace cat_density=f2.cat_density if (financialYearEnd==1879|financialYearEnd==1889|financialYearEnd==1899|financialYearEnd==1909)
replace cat_density=f1.cat_density if (financialYearEnd==1880|financialYearEnd==1890|financialYearEnd==1900|financialYearEnd==1910)

** We don't have houses information after 1901, so use the 1901 crowding after that point
replace cat_crowding=l1.cat_crowding if financialYearEnd>1901&crowding==.

// Create inflation adjusted based to 1883
// Adjust inflation to financial years
sort id financialYearEnd
gen newPrice=(3/4)*price+(1/4)*f1.price
summ newPrice if financialYearStart==1883
foreach i in expCurrentTotal recCurrentTransfers recCurrentProperty  rateableValueComb {
	gen pc`i'Real=pcN`i'*(r(mean)/newPrice)
}
drop price 
label var newPrice "Rousseaux price index adjusted to financial years"

#delimit; 
** Create dummy variables identifying whether nonmb after particular year ;
forvalues x=1883/1904 {;
	gen post`x'=0 if financialYearStart<=`x';
	replace post`x'=1 if financialYearStart>`x';
	gen nonmb_x_post`x'=1 if nonmb==1&post`x'==1;
	replace nonmb_x_post`x'=0 if nonmb==0|post`x'==0;
	label var post`x' "Dummy variable indicating financialYearStart>`x'";
	label var nonmb_x_post`x' "Interaction between post`x' and nonmb indicator";
};

// Time trends
gen time=financialYearEnd-1884;
gen timesq=time^2;
gen timecu=time^3;
gen timequ=time^4;	
gen popGrowth=populationGrowth; /** Need to rename so variables below are right length **/
gen pcrateVal=pcNrateableValueComb; /** Need to rename so variables below are right length **/
foreach var in population popGrowth density crowd pctService pctAgriculture pctIndustrial1881  {;
	gen temp=`var' if financialYearEnd==1881&excludeStage1==0;
	xtile temp2=temp,nq(4);
	bysort id: egen ct_`var'=max(temp2);
	drop temp temp2;
	foreach tvar of varlist time timesq timecu timequ {;
		forvalues x=1/4 {;
			gen `tvar'_x_`var'_`x'=`tvar' if ct_`var'==`x';
			replace `tvar'_x_`var'_`x'=0 if ct_`var'~=`x';
		};
	};
	drop ct_`var';
};

foreach var in pcNoutLoansTotal pcrateVal  {;
	gen temp=`var' if financialYearEnd==1884&excludeStage1==0;
	xtile temp2=temp,nq(4);
	bysort id: egen ct_`var'=max(temp2);
	drop temp temp2;
	foreach tvar of varlist time timesq timecu timequ {;
		forvalues x=1/4 {;
			gen `tvar'_x_`var'1884_`x'=`tvar' if ct_`var'==`x';
			replace `tvar'_x_`var'1884_`x'=0 if ct_`var'~=`x';
		};
	};
	drop ct_`var';
};

drop popGrowth pcrateVal;
	
// Flexible linear time trends;
gen timeNonMBPost1883=(financialYearStart-1883)*nonmb*post1883; 
gen timeNonMBPost1894=(financialYearStart-1894)*nonmb*post1894; 
gen timeNonMBPost1896=(financialYearStart-1896)*nonmb*post1896; 
 
forvalues x=1883/1902 {;
	quietly gen dummyYear`x'=(financialYearStart==`x');
	quietly gen nonmb_x_dummyYear`x'=nonmb*dummyYear`x';
};

// Generate unit specific linear trends
levelsof id, local(list);
foreach i in `list' {;
	quietly gen individualTime_`i'=time if id==`i';
	quietly replace individualTime_`i'=0 if id~=`i';
	quietly gen individualTimeSq_`i'=timesq if id==`i';
	quietly replace individualTimeSq_`i'=0 if id~=`i';
};	
#delimit cr

// Revenue and spending as percentages as total, for figures 7 and 8
foreach i in Tax Transfers Property Fees Other {
	gen pctNrecCurrent`i'=(NrecCurrent`i'/NrecCurrentTotal)*100
}

foreach i in Water Streets Sewers Justice Education Other Gas OtherLAs Loans OtherPW {
	gen pctNexpCurrent`i'=(NexpCurrent`i'/NexpCurrentTotal)*100
}

drop Nrec* Nexp* Nout*  pcNexpCurrentJustice pcNexpCurrentEducation pcNrecCurrentOther

// Interactions with density and agriculture (for appendix table C7)
// Dummy variables for median of agriculture and industrial as share of 1881 workforce
foreach var of varlist pctAgriculture pctIndustrialMining1881 {
	gen temp=`var' if financialYearEnd==1881&excludeStage1==0
	xtile Temp`var'=temp,nq(2)
	replace Temp`var'=Temp`var'-1
	bysort id: egen dumm`var'=max(Temp`var')
	drop temp Temp`var'
}
gen temp=density if financialYearEnd==1891&excludeStage1==0
xtile Tempdensity=temp,nq(2)
replace Tempdensity=Tempdensity-1
bysort id: egen dummdensity=max(Tempdensity)
drop temp Tempdensity

gen nonmb_x_post1894_x_agric=nonmb_x_post1894*dummpctAgric
gen nonmb_x_post1894_x_nonagric=nonmb_x_post1894*(1-dummpctAgric)
gen nonmb_x_post1894_x_MC=nonmb_x_post1894*middleClassTown
gen nonmb_x_post1894_x_UC=nonmb_x_post1894*(1-middleClassTown)
gen nonmb_x_post1894_x_dense=nonmb_x_post1894*dummdensity
gen nonmb_x_post1894_x_nondense=nonmb_x_post1894*(1-dummdensity)

gen post1894_x_MC=post1894*middleClassTown
gen post1894_x_agric=post1894*dummpctAgric
gen post1894_x_dense=post1894*dummdensity

gen nonmb_x_post1894_x_indust=nonmb_x_post1894*dummpctIndust
gen post1894_x_indust=post1894*dummpctIndust

// Variable labels
label var nonmb_x_post1894_x_agric "Unincorp*post1894*Agricultural"
label var nonmb_x_post1894_x_nonagric "Unincorp*post1894*(1-Agricultural)"
label var nonmb_x_post1894_x_indust "Unincorp*post1894*Industrial"
label var nonmb_x_post1894_x_dense "Unincorp*post1894*Dense"
label var nonmb_x_post1894_x_nondense "Unincorp*post1894*(1-dense)"
label var nonmb_x_post1894 "Unincorp*post1894"
label var nonmb_x_post1894_x_MC "Unincorp*post1894*middClass"
label var nonmb_x_post1894_x_UC "Unincorp*post1894*upperClass"
label var post1894_x_MC "post1894*MiddleClass"
label var post1894_x_agric "post1894*Agricultural"
label var post1894_x_indust "post1894*Industrial"
label var post1894 "post1894"
label var post1894_x_dense "post1894*Dense"
label var dummdensity "Above or below median density"
label var dummpctIndustrialMining1881 "Above or below % industry"
label var dummpctAgriculture1881 "Above or below % agriculture"
    
******************************************************************************************************************************
// 3) PREPARE FOR REGREESION
// Trim dataset to years 1884-1903,  create standardized variables for regression and create variable labels
******************************************************************************************************************************
// Keep only years used in analysis
keep if financialYearEnd>=1884&financialYearEnd<=1903

// Create indicator to label observations with missing variables 
// This is used to ensure consistent dataset across specifications with/without controls
gen forRegression=1  
label var forRegression "=0 if has some missing control variables, 1 otherwise"

#delimit;
foreach var of varlist pcNexpCurrentTotal pcNrateableValueComb pcNrecCurrentProperty 
	winterTemp autumnTemp springTemp summerTemp autumnPrecipitation springPrecipitation summerPrecipitation winterPrecipitation
	pcNrecCurrentTransfers cat_population cat_populationGrowth cat_crowding cat_density {;
	replace forRegression=0 if `var'==.;
}; 

// Create standardized variables
foreach var of varlist pcNexpCurrent* pcNrecCurrent* *Real 
	pcNrateableValueComb population pcNoutLoansTotal 
	poorRatePerCapita poorRatePerCapitaAdjusted pauperReliefPerCapita {;
		local l`var' : variable label `var';
		capture drop sd_`var';
		gen temp=`var' if excludeStage1==0;
		egen sd_`var'=std(temp);
		label var sd_`var' "`l`var'' (standardized)";
		drop temp;
};
#delimit cr

// Variable labels for regression tables
label var sd_pcNrecCurrentTransfersTotal "Grants p.c."
label var sd_pcNrateableValueComb "Tax base p.c."
label var sd_pcNrecCurrentProperty "Property receipts p.c."
label var sd_pcrecCurrentTransfersReal "Grants p.c."
label var sd_pcrateableValueCombReal "Tax base p.c."
label var sd_pcrecCurrentPropertyReal "Property receipts p.c."
label var nonmb "Unincorporated"
label var nonmb_x_post1894 "Unincorporated*post1894"
label var post1894 "post1894"

************************************************************************
*** Save file to be used in regressions
************************************************************************	
sort id financialYearEnd
quietly compress
save "$datapath/Chapman_QJPS_2018analysis.dta",replace

